filterlist — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# filterlist

Controls to filter data

class `camelot.view.controls.filterlist.` `FilterList`(items, parent)

  A list with filters that can be applied on a query in the tableview

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus